function [ h ] = h_water_pipe(q, d)
% heat transfer coefficient at the water-pipe interface (W/m/K)
% Parameters
% q : water mass flow (kg/s)
% d : inner pipe diameter (m)

% Water data
rho = 1000; % density kg/m3
lambda = 0.58; % thermal conductivity W/m/K, https://en.wikipedia.org/wiki/Water
mu = 1e-3; % dynamic viscosity kg/m/s, https://en.wikipedia.org/wiki/Water
Cp = 4185; % specific heat J/kg/K

% average flow speed:
r = d/2;
U = q/rho/(pi*r^2);

% Prandtl number
Pr=Cp*mu/lambda % "around 7" for water, Wikipedia
% Reynolds number
Re=rho*U*d/mu

% Nusselt number, empirically correlated to Re,Pr,
% (valid for turbulent pipe flow)
Nu=0.023*Re^0.8*Pr^0.33;
% alternatives:
% 0.027*... in http://www.che.ufl.edu/ren/unit-ops-lab/ech4224L/HE/HE-theory.pdf
% ...*Pr^0.4 in https://en.wikipedia.org/wiki/Nusselt_number, Dittus-Boelter equation

h=Nu*lambda/d %  W/m/K

end

